#!/usr/bin/python3
#
# Kindersicherung -- Script zur Aktivierung des JuProgDNS 
#
# Copyright (C) 2020  Tobias Petri
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program (LICENSE_GPL3) file.
#    If not, see <http://www.gnu.org/licenses/>.
# 
# Comments & Additions are welcome (tools@tobiaspetri.net)
# 

import sys
version = "2020-05-31"

def copyright():
    sys.stderr.write("""kindersicherung.py -- Copyright (C) 2020  Tobias Petri
	
(build {})

    This program comes with ABSOLUTELY NO WARRANTY; 
    This is free software, and you are welcome to redistribute it
    under certain conditions (see LICENSE file)
    ----\n\n""".format(version)) 
copyright()

import getopt
import re
from shutil import copyfile

age = 0 
try:
	if sys.argv[1] == "off":
		age = 18 
	else:
		age = int(sys.argv[1])
except:
	print("""kindersicherung.py [<age>|off]

ARGS
	age		Ganze Zahl, das Alter des Kindes	
	off		Deaktivierung der Kindersicherung

DESC

	Dieses Skript ändert den DNS auf einen dem Alter zugeschnittenen JusProgDNS Server, oder deaktiviert ihn. Auf diese Weise einem aktiven User rasch ein anderes Jugendschutzprofil zugewiesen werden.
	Es stützt sich auf die freien Server von JusProgDNS zu: www.jusprogdns.com

VOR DEM ERSTEN START
	Achtung: um die Kindersicherung zu aktivieren muss einmalig in der Datei 
	`/etc/dhcp/dhclient.conf` der Kommentar 

		# Kindersicherung

	in eine eigene Zeile geschrieben werden, z.B. hinter den beispielhaften 'supersede' Kommandos.

	Sinnvoll ist ein Aufruf per Skript:

		#!/bin/bash
		# kindersicherung.sh
		sudo python3 ${HOME}/bin/kindersicherung.py $@
		sudo service network-manager restart

""")
	sys.exit(0)


dhconf = "/etc/dhcp/dhclient.conf"
dhconf_bak = dhconf + ".bak"

remove_pattern = r"supersede domain-name-servers 109\.235\.61.*"

if age < 6:
	agecommand="supersede domain-name-servers 109.235.61.162,194.97.50.3;"
elif age < 12:
	agecommand="supersede domain-name-servers 109.235.61.171,194.97.50.4;"
elif age < 16:
	agecommand="supersede domain-name-servers 109.235.61.200,194.97.50.5;"
elif age < 18:
	agecommand="supersede domain-name-servers 109.235.61.210,194.97.50.6;"
else:
	agecommand=None

copyfile(dhconf, dhconf_bak)

try:
	out = []
	with open(dhconf) as dc:
		for l in dc:
			l = l.strip()
			if re.search(remove_pattern, l) is None:
				out.append(l)
			else:
				print("removing: {}".format(l))

			if "Kindersicherung" in l:
				if agecommand is not None:
					out.append(agecommand)
					print("adding: {}".format(agecommand))
				
	open(dhconf, "w").write("\n".join(out))
	print("""Bitte den Netzwerk-Manager neu starten:

	sudo service network-manager restart

	""")

except:
	copyfile(dhconf_bak, dhconf)
	print("something went wrong, change revoked")
	raise
